@@ -4,14 +4,18 @@ function(X,m,kmin=1,kmax=20,plotres=TRUE,parallel=FALSE,cpus=2,iLLE=FALSE){
 	#set parameters
 	N <- dim(X)[1]
 	if( kmax>=N ) kmax <- N - 1 #more neighbourse than points doesnt make sense
-	if( .Platform$OS.type=="unix" ) dev <- "/dev/null" else dev <- "nul"	
+	if( .Platform$OS.type=="windows" ) dev <- "nul" else dev <- "/dev/null"	
 	
 	#set up parallel computation
 	if( parallel==TRUE) sfInit( parallel=TRUE, cpus=cpus ) else sfInit( parallel=FALSE ) 
+	#require lle for every node
+	options("warn"=-1)
+	sfLibrary( lle )
+	options("warn"=0)
+	
 	
 	perform_calc <- function( k, X, m, iLLE=FALSE ){
 
-		require(lle) #for every single thread
 		N <- dim(X)[1]
 
 		#perform LLE
@@ -41,7 +45,7 @@ function(X,m,kmin=1,kmax=20,plotres=TRUE,parallel=FALSE,cpus=2,iLLE=FALSE){
 
 	if( plotres ){
 		par( mar=c(5,5,4,2)+0.1 )
-		plot( res$k, res$rho, type="b", xlab="k", ylab=expression(1-rho^2) )
+		plot( res$k, res$rho, type="b", xlab="k", ylab=expression(1-rho^2), main="" )
 		abline(h=min(res$rho,na.rm=TRUE),col="red")
 		grid()
 	} else cat( "best k:",head(res$k[order(res$rho)],3), "\n\n" )	
